Module reduced

!Based on the search in JOSA B v30, p2113, y2013 

    use working_precision
    
Implicit None

Contains

Subroutine reducedRadRI(p,minRad,maxRad,iRad,nRad,minRI,maxRI,iRI,nRI,origVal,RIfact,radfact,mlow)
    
    !assign the new boundaries based on the search without dispersion
    real(wp), allocatable :: p(:) !in this subroutine initial guesses are determined

    real(wp) :: minRad, maxRad, iRad !Range of possible radii
    real(wp) :: minRI, maxRI, iRI !Range of possible refractive index
    integer :: nRI,nRad !number of steps in RI and radius
    real(wp) :: origVal(6) !stores the original values of minRad,maxRad,iRad,minRI,maxRI,iRI during reduced search

    real(wp) :: RIfact, radfact !factors used in the RI and radius for the reduced search

    integer :: mlow !starting integer for mode table in RI 
    
    maxRad=p(1)*(1.0_wp+Radfact) !This can be maxRad=p(1), but doesn't add that much time to search
    minRad=p(1)*(1.0_wp-Radfact)
    minRI=p(2)*(1.0_wp-RIfact)
    maxRI=p(2)*(1.0_wp+RIfact)
    
    !make sure these parameters are within the original bounds
    If(minRad.LT.origVal(1))Then
        minRad=origVal(1)
    End if
    
    If(maxRad.GT.origVal(2))Then
        maxRad=origVal(2)
    End if
    
    If(minRI.LT.origVal(4))Then
        minRI=origVal(4)
    End if
    
    If(maxRI.GT.origVal(5))Then
        maxRI=origVal(5)
    End if

    mlow = NInt((minRI-origVal(4))/iRI) + 1

    nRad = NInt((maxRad-minRad)/iRad) + 1
    nRI = NInt((maxRI-minRI)/iRI) + 1

End subroutine

Subroutine storeParameters(minRad,maxRad,iRad,nRad,minRI,maxRI,iRI,nRI,origVal,sType)

    real(wp) :: minRad, maxRad, iRad !Range of possible radii
    real(wp) :: minRI, maxRI, iRI !Range of possible refractive index
    integer :: nRI,nRad !number of steps in RI and radius
    real(wp) :: origVal(6) !stores the original values of minRad,maxRad,iRad,minRI,maxRI,iRI during reduced search

    integer :: sType !0: store, 1: retrieve

    If(sType.EQ.0)Then
        origVal(1)=minRad
        origVal(2)=maxRad
        origVal(3)=iRad
        origVal(4)=minRI
        origVal(5)=maxRI
        origVal(6)=iRI
    Else if(sType.EQ.1) Then
        minRad=origVal(1)
        maxRad=origVal(2)
        iRad=origVal(3)
        minRI=origVal(4)
        maxRI=origVal(5)
        iRI=origVal(6)
        nRad = NInt((maxRad-minRad)/iRad) + 1
        nRI = NInt((maxRI-minRI)/iRI) + 1
    End if 

End subroutine

End Module 